==> safecheck-3.0.14.jar: safecheck/sqls/SafecheckSummary.sql <==
select f_checker_name,
       yuefeng,
       SUM(isnull(yijian, 0))  AS yijian,
       SUM(isnull(jujian, 0))  AS jujian,
       SUM(isnull(ruhu, 0)) AS ruhu,
       SUM(isnull(daofang, 0)) AS daofang,
       SUM(isnull(yinhuan, 0)) AS yinhuan
from (
         select replace(substring(isnull(f_upload_date, '1399-01-01 00:00:00'), 0, 8), '-', '') yuefeng,
                f_checker_name,
                CASE
                    WHEN f_state = '已检'
                        AND F_NO_CHECKPLAN = '无计划安检'
                        THEN 1
                    ELSE 0
                    END AS   yijian,
                CASE
                    WHEN f_entry_status = '入户'
                        AND F_NO_CHECKPLAN = '无计划安检'
                        THEN 1
                    ELSE 0
                    END AS ruhu,
                CASE
                    WHEN f_entry_status = '到访不遇'
                        AND F_NO_CHECKPLAN = '无计划安检'
                        THEN 1
                    ELSE 0
                    END AS daofang,
                CASE
                    WHEN f_entry_status = '拒检'
                        AND F_NO_CHECKPLAN = '无计划安检'
                        THEN 1
                    ELSE 0
                    END AS   jujian,
                CASE
                    WHEN f_defect_content like '%有隐患%'
                        AND F_NO_CHECKPLAN = '无计划安检'
                        THEN 1
                    ELSE 0
                    END AS   yinhuan,
                f_upload_date
         from t_check_paper  with (nolock)  where f_filialeid in {f_filiale_id}
     ) paper
where f_checker_name is not null
  and {condition}
group by f_checker_name, yuefeng
order by yuefeng desc

==> safecheck-3.1.66.jar: safecheck/sqls/SafecheckSummary.sql <==
select f_checker_name,
       yuefeng,
       SUM(isnull(yijian, 0))  AS yijian,
       SUM(isnull(jujian, 0))  AS jujian,
       SUM(isnull(ruhu, 0)) AS ruhu,
       SUM(isnull(daofang, 0)) AS daofang,
       SUM(isnull(yinhuan, 0)) AS yinhuan,
       case when SUM(isnull(ruhu, 0)) = 0 then '0.00%' else
            CONVERT(varchar,CONVERT(decimal(10, 2), (SUM(isnull(ruhu, 0)) / NULLIF(SUM(isnull(yijian, 0)), 0))))+ '%' end AS ruhu_bv
from (
         select replace(substring(isnull(f_upload_date, '1399-01-01 00:00:00'), 0, 8), '-', '') yuefeng,
                f_checker_name,
                CASE
                    WHEN f_state = '已检'
                        AND F_NO_CHECKPLAN = '无计划安检'
                        THEN 1
                    ELSE 0
                    END AS   yijian,
                CASE
                    WHEN f_entry_status = '入户'
                        AND F_NO_CHECKPLAN = '无计划安检'
                        THEN 1
                    ELSE 0
                    END AS ruhu,
                CASE
                    WHEN f_entry_status = '到访不遇'
                        AND F_NO_CHECKPLAN = '无计划安检'
                        THEN 1
                    ELSE 0
                    END AS daofang,
                CASE
                    WHEN f_entry_status = '拒检'
                        AND F_NO_CHECKPLAN = '无计划安检'
                        THEN 1
                    ELSE 0
                    END AS   jujian,
                CASE
                    WHEN f_defect_content like '%有隐患%'
                        AND F_NO_CHECKPLAN = '无计划安检'
                        THEN 1
                    ELSE 0
                    END AS   yinhuan,
                f_upload_date,
                f_check_type
         from t_check_paper  with (nolock)  where f_filialeid in {f_filiale_id}
     ) paper
where f_checker_name is not null
  and {condition}
group by f_checker_name, yuefeng
order by yuefeng desc
